﻿using System.Runtime.InteropServices;

namespace UnicsLib
{
    class CLog
    {
        /* ------------------------------------------------------------------------------------------------------------- */
        /* DLL Import :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: */
        /* ------------------------------------------------------------------------------------------------------------- */
#if WIN64
        private const string DLL_NAME = "UnicoMonitorClient64.dll";
#else
        private const string DLL_NAME = "UnicoMonitorClient.dll";
#endif

        [DllImport(DLL_NAME, EntryPoint = "StartLogPrinter")]
        private static extern uint StartLogPrinter(string DestIPAdrs, int DestPortNo, string Prefix, int ConsoleSW);

        [DllImport(DLL_NAME, EntryPoint = "StopLogPrinter")]
        private static extern uint StopLogPrinter(uint Handle);

        [DllImport(DLL_NAME, EntryPoint = "WaitLogMonitorReady")]
        private static extern uint WaitLogMonitorReady(uint Handle, uint TimoMsec);

        [DllImport(DLL_NAME, EntryPoint = "LogPrint")]
        private static extern uint LogPrint(uint Handle, string buff);


        /* ------------------------------------------------------------------------------------------------------------- */
        /* DLL クラス化 :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: */
        /* ------------------------------------------------------------------------------------------------------------- */
        private uint m_Handle = 0;

        public CLog(string DestIPAdrs, int DestPortNo, string Prefix, int ConsoleSW)
        {
            m_Handle = StartLogPrinter(DestIPAdrs, DestPortNo, Prefix, ConsoleSW);
        }

        ~CLog()
        {
            if (m_Handle != 0)
            {
                StopLogPrinter(m_Handle);
                m_Handle = 0;
            }
        }

        public uint WaitMonitorReady( uint TimoMsec )
        {
            return WaitLogMonitorReady(m_Handle, TimoMsec);
        }

        public uint Print(string buff)
        {
            return LogPrint(m_Handle, buff);
        }
    }
}
